@@ -1,8 +1,8 @@
 import abc
 import pandas as pd
-from common.database_client import DataBaseClient
-from common.file_client import FileClient
-from common.logger import Logger
+from nemuru_ml.common.database_client import DataBaseClient
+from nemuru_ml.common.file_client import FileClient
+from nemuru_ml.common.logger import Logger
 
 
 class Etl(abc.ABC):
