@@ -24,6 +24,10 @@ class Training(abc.ABC):
     def __subclasshook__(cls, subclass):
         return (hasattr(subclass, 'split_data') and
                 callable(subclass.split_data) and
+                hasattr(subclass, 'input_schema') and
+                callable(subclass.input_schema) and
+                hasattr(subclass, 'output_schema') and
+                callable(subclass.output_schema) and
                 hasattr(subclass, 'fit') and
                 callable(subclass.fit) and
                 hasattr(subclass, 'model_uri') and
@@ -50,6 +54,16 @@ class Training(abc.ABC):
     def model(self):
         return self._model
 
+    @abc.abstractmethod
+    def input_schema(self):
+        """Load in the data set"""
+        raise NotImplementedError
+
+    @abc.abstractmethod
+    def output_schema(self):
+        """Load in the data set"""
+        raise NotImplementedError
+
     @abc.abstractmethod
     def split_data(self, data: pd.DataFrame) -> Tuple[pd.DataFrame, pd.DataFrame]:
         """Load in the data set"""
